"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDynamicBlocks = exports.filterDynamicBlocks = void 0;
const settings_1 = require("@ewizardjs/settings");
const system_settings_1 = require("@ewizardjs/system-settings");
const fs_1 = require("fs");
const path_1 = require("path");
const client_1 = require("../client");
Object.defineProperty(exports, "filterDynamicBlocks", { enumerable: true, get: function () { return client_1.filterDynamicBlocks; } });
const utils_1 = require("../utils");
async function getDynamicBlocks(contentPath) {
    var _a;
    try {
        const { targetCLM, metadata } = await (0, settings_1.getRawWithoutCache)(contentPath);
        const currentClm = (_a = targetCLM === null || targetCLM === void 0 ? void 0 : targetCLM.code) !== null && _a !== void 0 ? _a : '';
        const currentPurpose = (0, utils_1.getCurrentPurpose)(metadata);
        const currentTheme = await (0, settings_1.getCurrentTheme)(contentPath);
        const { blocksManifest, blocksThemes } = await (0, system_settings_1.getByPath)(contentPath, 'path');
        const pathToBlocks = (0, path_1.join)(contentPath, blocksManifest);
        const pathToBlocksThemes = (0, path_1.join)(contentPath, blocksThemes);
        const { components = [] } = await readJson(pathToBlocks);
        const { themes = {} } = await readJson(pathToBlocksThemes);
        return (0, client_1.filterDynamicBlocks)({
            blocksList: components,
            blocksThemes: themes,
            currentTheme,
            currentClm,
            currentPurpose,
        });
    }
    catch (_b) {
        return [];
    }
}
exports.getDynamicBlocks = getDynamicBlocks;
async function readJson(filePath) {
    return JSON.parse(await fs_1.promises.readFile(filePath, 'utf8'));
}
//# sourceMappingURL=index.js.map